@@ -104,6 +104,7 @@ block_exec = function(options) {
     res.before = run_hooks(before = TRUE, options)
     engine = get_engine(options$engine)
     output = in_dir(input_dir(), engine(options))
+    if (is.list(output)) output = unlist(output)
     res.after = run_hooks(before = FALSE, options)
     output = paste(c(res.before, output, res.after), collapse = '')
     output = knit_hooks$get('chunk')(output, options)
@@ -259,7 +260,11 @@ block_exec = function(options) {
     # make sure all objects to be saved exist in env
     objs = intersect(c(objs, obj.new), ls(env, all.names = TRUE))
     if (options$autodep) {
-      cache$objects(objs, code, options$label, options$cache.path)
+      # you shall manually specify global object names if find_symbols() is not reliable
+      cache$objects(
+        objs, options$cache.globals %n% find_symbols(code), options$label,
+        options$cache.path
+      )
       dep_auto()
     }
     if (options$cache < 3) {
@@ -379,7 +384,8 @@ merge_class = function(res, class = c('source', 'message', 'warning')) {
     if (idx2 - idx1 == 1) {
       res2 = res[[idx2]]
       # merge warnings/messages only if next one is identical to previous one
-      if (class == 'source' || identical(res1, res2)) {
+      if (class == 'source' || identical(res1, res2) ||
+          (class == 'message' && !grepl('\n$', tail(res1[[el]], 1)))) {
         res[[k1]][[el]] = c(res[[k1]][[el]], res2[[el]])
         k2 = c(k2, idx2)
       } else {
@@ -416,7 +422,10 @@ call_inline = function(block) {
   in_dir(input_dir(), inline_exec(block))
 }
 
-inline_exec = function(block, envir = knit_global(), hook = knit_hooks$get('inline')) {
+inline_exec = function(
+  block, envir = knit_global(), hook = knit_hooks$get('inline'),
+  hook_eval = knit_hooks$get('evaluate.inline')
+) {
 
   # run inline code and substitute original texts
   code = block$code; input = block$input
@@ -424,8 +433,7 @@ inline_exec = function(block, envir = knit_global(), hook = knit_hooks$get('inli
 
   loc = block$location
   for (i in 1:n) {
-    v = withVisible(eval(parse_only(code[i]), envir = envir))
-    res = if (v$visible) knit_print(v$value, inline = TRUE, options = opts_chunk$get())
+    res = hook_eval(code[i], envir)
     if (inherits(res, 'knit_asis')) res = wrap(res, inline = TRUE)
     d = nchar(input)
     # replace with evaluated results
