@@ -11,18 +11,28 @@ new_defaults = function(value = list()) {
       }
     }
   }
-  set = function(...) {
+  resolve = function(...) {
     dots = list(...)
     if (length(dots) == 0) return()
     if (is.null(names(dots)) && length(dots) == 1 && is.list(dots[[1]]))
       if (length(dots <- dots[[1]]) == 0) return()
-    defaults <<- merge(dots)
+    dots
+  }
+  set = function(...) {
+    dots = resolve(...)
+    if (length(dots)) defaults <<- merge(dots)
     invisible(NULL)
   }
   merge = function(values) merge_list(defaults, values)
   restore = function(target = value) defaults <<- target
+  append = function(...) {
+    dots = resolve(...)
+    for (i in names(dots)) dots[[i]] <- c(defaults[[i]], dots[[i]])
+    if (length(dots)) defaults <<- merge(dots)
+    invisible(NULL)
+  }
 
-  list(get = get, set = set, merge = merge, restore = restore)
+  list(get = get, set = set, append = append, merge = merge, restore = restore)
 }
 
 #' Default and current chunk options
@@ -39,10 +49,7 @@ new_defaults = function(value = list()) {
 #' the options in this chunk itself, and that is why we often need to set global
 #' options in a separate chunk.
 #'
-#' Below is a list of default chunk options, retrieved via
-#' \code{opts_chunk$get()}:
-#'
-#' \Sexpr[results=verbatim]{str(knitr::opts_chunk$get())}
+#' See \code{str(knitr::opts_chunk$get())} for a list of default chunk options.
 #' @references Usage: \url{https://yihui.name/knitr/objects/}
 #'
 #'   A list of available options:
@@ -134,10 +141,7 @@ set_alias = function(...) {
 #' correspond to options in \code{opts_knit}. This can be useful to set package
 #' options in \file{~/.Rprofile} without loading \pkg{knitr}.
 #'
-#'  Below is a list of default package options, retrieved via
-#' \code{opts_knit$get()}:
-#'
-#' \Sexpr[results=verbatim]{str(knitr::opts_knit$get())}
+#' See \code{str(knitr::opts_knit$get())} for a list of default package options.
 #' @references Usage: \url{https://yihui.name/knitr/objects/}
 #'
 #'   A list of available options:
