@@ -10,7 +10,11 @@
   source = .out.hook, output = .out.hook, warning = .out.hook,
   message = .out.hook, error = .out.hook, plot = .plot.hook,
   inline = .inline.hook, chunk = .out.hook, text = identity,
-  evaluate = evaluate::evaluate, document = identity
+  evaluate.inline = function(code, envir = knit_global()) {
+    v = withVisible(eval(parse_only(code), envir = envir))
+    if (v$visible) knit_print(v$value, inline = TRUE, options = opts_chunk$get())
+  },
+  evaluate = function(...) evaluate::evaluate(...), document = identity
 )
 
 #' Hooks for R code chunks, inline R code and output
@@ -19,9 +23,9 @@
 #' arguments and returns desired output. The object \code{knit_hooks} is used to
 #' access or set hooks in this package.
 #' @export
-#' @references Usage: \url{http://yihui.name/knitr/objects}
+#' @references Usage: \url{https://yihui.name/knitr/objects/}
 #'
-#' Components in \code{knit_hooks}: \url{http://yihui.name/knitr/hooks}
+#' Components in \code{knit_hooks}: \url{https://yihui.name/knitr/hooks/}
 #' @examples knit_hooks$get('source'); knit_hooks$get('inline')
 knit_hooks = new_defaults(.default.hooks)
 
@@ -54,7 +58,7 @@ hook_suppress = function(x, options) {
 #' \code{opts_hooks$set(FOO = function(options) { options })} (you can manipuate
 #' the \code{options} argument in the function and return it), the hook function
 #' will be called to update the chunk options.
-#' @references \url{http://yihui.name/knitr/hooks}
+#' @references \url{https://yihui.name/knitr/hooks/}
 #' @export
 #' @examples # make sure the figure width is no smaller than fig.height
 #' opts_hooks$set(fig.width = function(options) {
