@@ -502,7 +502,7 @@ msg_wrap = function(message, type, options) {
     list(c(knit_log$get(type), paste0('Chunk ', options$label, ':\n  ', message))),
     type
   ))
-  msg_sanitize(message, type)
+  message = msg_sanitize(message, type)
   knit_hooks$get(type)(comment_out(message, options$comment), options)
 }
 
@@ -572,7 +572,7 @@ wrap.knit_image_paths = function(x, options = opts_chunk$get(), inline = FALSE)
   }
   dpi = attr(x, 'dpi') %n% options$dpi
   paste(unlist(lapply(seq_along(x), function(i) {
-    options$fig.cur = i
+    options$fig.cur = plot_counter()
     if (is.null(options[['out.width']]))
       options['out.width'] = list(raster_dpi_width(x[i], dpi))
     hook_plot(x[i], reduce_plot_opts(options))
