@@ -262,9 +262,15 @@ fix_options = function(options) {
 
   options$eval = unname(options$eval)
 
-  # if aspect ratio is specified, calculate figure height
-  if (is.numeric(options$fig.asp)) {
-    options$fig.height = options$fig.width * options$fig.asp
+  # handle aspect ratio/figure dimensions; give priority to fig.dim, with
+  # warning (seems relatively more likely as user's intention in case when both
+  # present) if aspect ratio is specified, calculate figure height
+  fix_asp = is.numeric(options$fig.asp)
+  if (length(options$fig.dim) == 2L) {
+    if (fix_asp) warning('The chunk option fig.asp is ignored since fig.dim is provided.')
+    options$fig.width = options$fig.dim[1L]; options$fig.height = options$fig.dim[2L]
+  } else {
+    if (fix_asp) options$fig.height = options$fig.width * options$fig.asp
   }
 
   # out.[width|height].px: unit in pixels for sizes
@@ -297,10 +303,47 @@ fix_options = function(options) {
   options
 }
 
+#' Check if the current output type is LaTeX or HTML
+#'
+#' The function \code{is_latex_output()} returns \code{TRUE} when the output
+#' format is LaTeX; it works for both \file{.Rnw} and R Markdown documents (for
+#' the latter, the two Pandoc formats \code{latex} and \code{beamer} are
+#' considered LaTeX output). The function \code{is_html_output()} only works for
+#' R Markdown documents.
+#'
+#' These functions may be useful for conditional output that depends on the
+#' output format. For example, you may write out a LaTeX table in an R Markdown
+#' document when the output format is LaTeX, and an HTML or Markdown table when
+#' the output format is HTML.
+#'
+#' Internally, the Pandoc output format of the current R Markdown document is
+#' stored in \code{knitr::\link{opts_knit}$get('rmarkdown.pandoc.to')}. By
+#' default, these formats are considered as HTML formats: \code{c('markdown',
+#' 'epub', 'html', 'html5', 'revealjs', 's5', 'slideous', 'slidy')}.
+#' @rdname output_type
+#' @export
+#' @examples knitr::is_latex_output()
+#' knitr::is_html_output()
+#' knitr::is_html_output(excludes = c('markdown', 'epub'))
 is_latex_output = function() {
   out_format('latex') || pandoc_to(c('latex', 'beamer'))
 }
 
+#' @param fmt A character vector of output formats to be checked. By default, it
+#'   is the current Pandoc output format.
+#' @param excludes A character vector of output formats that should not be
+#'   considered as the HTML format.
+#' @rdname output_type
+#' @export
+is_html_output = function(fmt = pandoc_to(), excludes = NULL) {
+  if (length(fmt) == 0) return(FALSE)
+  if (grepl('^markdown', fmt)) fmt = 'markdown'
+  if (fmt == 'epub3') fmt = 'epub'
+  fmts = c('markdown', 'epub', 'html', 'html4', 'html5', 'revealjs', 's5', 'slideous', 'slidy')
+  fmt %in% setdiff(fmts, excludes)
+}
+
+
 # turn percent width to LaTeX unit, e.g. out.width = 30% -> .3\linewidth
 percent_latex_width = function(x) {
   if (!is.character(x)) return(x)
@@ -357,7 +400,8 @@ pandoc_from = function() {
   opts_knit$get('rmarkdown.pandoc.from') %n% 'markdown'
 }
 
-pandoc_fragment = function(text, to, from = pandoc_from()) {
+pandoc_fragment = function(text, to = pandoc_to(), from = pandoc_from()) {
+  if (length(text) == 0) return(text)
   f1 = tempfile('pandoc', '.', '.md'); f2 = tempfile('pandoc', '.')
   on.exit(unlink(c(f1, f2)), add = TRUE)
   writeLines(enc2utf8(text), f1, useBytes = TRUE)
@@ -676,9 +720,13 @@ set_html_dev = function() {
   if (!is.null(opts_chunk$get('dev'))) return()
   # in some cases, png() does not work (e.g. options('bitmapType') == 'Xlib' on
   # headless servers); use svg then
-  opts_chunk$set(dev = if (inherits(try_silent({
+  opts_chunk$set(dev = if (png_available()) 'png' else 'svg')
+}
+
+png_available = function() {
+  !inherits(try_silent({
     f = tempfile(); on.exit(unlink(f)); grDevices::png(f); grDevices::dev.off()
-  }), 'try-error')) 'svg' else 'png')
+  }), 'try-error')
 }
 
 # locate kpsewhich especially for Mac OS because /usr/texbin may not be in PATH
@@ -766,9 +814,9 @@ same_file = function(f1, f2) {
 
 # a restricted version of is.numeric (e.g. do not treat chron::chron() as
 # numeric since their behavior may be somewhat unpredictable, e.g. through
-# round(), #1118)
+# round(), #1118); see #1396 for difftime
 is_numeric = function(x) {
-  class(x)[1] %in% c('numeric', 'integer')
+  class(x)[1] %in% c('numeric', 'integer', 'difftime')
 }
 
 # create \label{x} or (\#x); the latter is current an internal hack for bookdown
@@ -945,3 +993,8 @@ writeUTF8 = function(text, file, ...) {
 }
 
 trimws = function(x) gsub('^\\s+|\\s+$', '', x)
+
+optipng = function(dir = '.') {
+  files = list.files(dir, '[.]png$', recursive = TRUE, full.names = TRUE)
+  for (f in files) system2('optipng', shQuote(f))
+}
